@@ -10,16 +10,19 @@ use crate::ffi::{ZStr, ZString};
 use crate::fs::CloneFlags;
 #[cfg(any(linux_raw, all(libc, any(target_os = "android", target_os = "linux"))))]
 use crate::fs::RenameFlags;
+use crate::fs::Timestamps;
 use crate::io::{self, OwnedFd};
+use crate::path::SMALL_PATH_BUFFER_SIZE;
 #[cfg(not(target_os = "wasi"))]
 use crate::process::{Gid, Uid};
 use crate::{imp, path};
 use alloc::vec::Vec;
 use imp::fd::{AsFd, BorrowedFd};
-#[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi",)))]
-use imp::fs::Dev;
-use imp::fs::{Access, AtFlags, Mode, OFlags, Stat};
-use imp::time::Timespec;
+#[cfg(not(target_os = "illumos"))]
+use imp::fs::Access;
+use imp::fs::{AtFlags, Mode, OFlags, Stat};
+#[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi")))]
+use imp::fs::{Dev, FileType};
 
 /// `openat(dirfd, path, oflags, mode)`—Opens a file.
 ///
@@ -43,7 +46,7 @@ pub fn openat<P: path::Arg, Fd: AsFd>(
     create_mode: Mode,
 ) -> io::Result<OwnedFd> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::openat(dirfd, path, oflags, create_mode))
+    path.into_with_z_str(|path| imp::fs::syscalls::openat(dirfd, path, oflags, create_mode))
 }
 
 /// `readlinkat(fd, path)`—Reads the contents of a symlink.
@@ -71,10 +74,11 @@ fn _readlinkat(dirfd: BorrowedFd<'_>, path: &ZStr, mut buffer: Vec<u8>) -> io::R
     // This code would benefit from having a better way to read into
     // uninitialized memory, but that requires `unsafe`.
     buffer.clear();
-    buffer.resize(256, 0_u8);
+    buffer.reserve(SMALL_PATH_BUFFER_SIZE);
+    buffer.resize(buffer.capacity(), 0_u8);
 
     loop {
-        let nread = imp::syscalls::readlinkat(dirfd, path, &mut buffer)?;
+        let nread = imp::fs::syscalls::readlinkat(dirfd, path, &mut buffer)?;
 
         let nread = nread as usize;
         assert!(nread <= buffer.len());
@@ -82,7 +86,8 @@ fn _readlinkat(dirfd: BorrowedFd<'_>, path: &ZStr, mut buffer: Vec<u8>) -> io::R
             buffer.resize(nread, 0_u8);
             return Ok(ZString::new(buffer).unwrap());
         }
-        buffer.resize(buffer.len() * 2, 0_u8);
+        buffer.reserve(1); // use `Vec` reallocation strategy to grow capacity exponentially
+        buffer.resize(buffer.capacity(), 0_u8);
     }
 }
 
@@ -97,7 +102,7 @@ fn _readlinkat(dirfd: BorrowedFd<'_>, path: &ZStr, mut buffer: Vec<u8>) -> io::R
 #[inline]
 pub fn mkdirat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, mode: Mode) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::mkdirat(dirfd, path, mode))
+    path.into_with_z_str(|path| imp::fs::syscalls::mkdirat(dirfd, path, mode))
 }
 
 /// `linkat(old_dirfd, old_path, new_dirfd, new_path, flags)`—Creates a hard
@@ -121,7 +126,7 @@ pub fn linkat<P: path::Arg, Q: path::Arg, PFd: AsFd, QFd: AsFd>(
     let new_dirfd = new_dirfd.as_fd();
     old_path.into_with_z_str(|old_path| {
         new_path.into_with_z_str(|new_path| {
-            imp::syscalls::linkat(old_dirfd, old_path, new_dirfd, new_path, flags)
+            imp::fs::syscalls::linkat(old_dirfd, old_path, new_dirfd, new_path, flags)
         })
     })
 }
@@ -141,7 +146,7 @@ pub fn linkat<P: path::Arg, Q: path::Arg, PFd: AsFd, QFd: AsFd>(
 #[inline]
 pub fn unlinkat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, flags: AtFlags) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::unlinkat(dirfd, path, flags))
+    path.into_with_z_str(|path| imp::fs::syscalls::unlinkat(dirfd, path, flags))
 }
 
 /// `renameat(old_dirfd, old_path, new_dirfd, new_path)`—Renames a file or
@@ -164,7 +169,7 @@ pub fn renameat<P: path::Arg, Q: path::Arg, PFd: AsFd, QFd: AsFd>(
     let new_dirfd = new_dirfd.as_fd();
     old_path.into_with_z_str(|old_path| {
         new_path.into_with_z_str(|new_path| {
-            imp::syscalls::renameat(old_dirfd, old_path, new_dirfd, new_path)
+            imp::fs::syscalls::renameat(old_dirfd, old_path, new_dirfd, new_path)
         })
     })
 }
@@ -190,7 +195,7 @@ pub fn renameat_with<P: path::Arg, Q: path::Arg, PFd: AsFd, QFd: AsFd>(
     let new_dirfd = new_dirfd.as_fd();
     old_path.into_with_z_str(|old_path| {
         new_path.into_with_z_str(|new_path| {
-            imp::syscalls::renameat2(old_dirfd, old_path, new_dirfd, new_path, flags)
+            imp::fs::syscalls::renameat2(old_dirfd, old_path, new_dirfd, new_path, flags)
         })
     })
 }
@@ -211,23 +216,29 @@ pub fn symlinkat<P: path::Arg, Q: path::Arg, Fd: AsFd>(
 ) -> io::Result<()> {
     let new_dirfd = new_dirfd.as_fd();
     old_path.into_with_z_str(|old_path| {
-        new_path.into_with_z_str(|new_path| imp::syscalls::symlinkat(old_path, new_dirfd, new_path))
+        new_path
+            .into_with_z_str(|new_path| imp::fs::syscalls::symlinkat(old_path, new_dirfd, new_path))
     })
 }
 
 /// `fstatat(dirfd, path, flags)`—Queries metadata for a file or directory.
 ///
+/// [`Mode::from_raw_mode`] and [`FileType::from_raw_mode`] may be used to
+/// interpret the `st_mode` field.
+///
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/fstatat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/fstatat.2.html
+/// [`Mode::from_raw_mode`]: crate::fs::Mode::from_raw_mode
+/// [`FileType::from_raw_mode`]: crate::fs::FileType::from_raw_mode
 #[inline]
 #[doc(alias = "fstatat")]
 pub fn statat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, flags: AtFlags) -> io::Result<Stat> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::statat(dirfd, path, flags))
+    path.into_with_z_str(|path| imp::fs::syscalls::statat(dirfd, path, flags))
 }
 
 /// `faccessat(dirfd, path, access, flags)`—Tests permissions for a file or
@@ -239,6 +250,7 @@ pub fn statat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, flags: AtFlags) -> io
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/faccessat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/faccessat.2.html
+#[cfg(not(target_os = "illumos"))]
 #[inline]
 #[doc(alias = "faccessat")]
 pub fn accessat<P: path::Arg, Fd: AsFd>(
@@ -248,7 +260,7 @@ pub fn accessat<P: path::Arg, Fd: AsFd>(
     flags: AtFlags,
 ) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::accessat(dirfd, path, access, flags))
+    path.into_with_z_str(|path| imp::fs::syscalls::accessat(dirfd, path, access, flags))
 }
 
 /// `utimensat(dirfd, path, times, flags)`—Sets file or directory timestamps.
@@ -263,11 +275,11 @@ pub fn accessat<P: path::Arg, Fd: AsFd>(
 pub fn utimensat<P: path::Arg, Fd: AsFd>(
     dirfd: &Fd,
     path: P,
-    times: &[Timespec; 2],
+    times: &Timestamps,
     flags: AtFlags,
 ) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::utimensat(dirfd, path, times, flags))
+    path.into_with_z_str(|path| imp::fs::syscalls::utimensat(dirfd, path, times, flags))
 }
 
 /// `fchmodat(dirfd, path, mode, 0)`—Sets file or directory permissions.
@@ -289,7 +301,7 @@ pub fn utimensat<P: path::Arg, Fd: AsFd>(
 #[doc(alias = "fchmodat")]
 pub fn chmodat<P: path::Arg, Fd: AsFd>(dirfd: &Fd, path: P, mode: Mode) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::chmodat(dirfd, path, mode))
+    path.into_with_z_str(|path| imp::fs::syscalls::chmodat(dirfd, path, mode))
 }
 
 /// `fclonefileat(src, dst_dir, dst, flags)`—Efficiently copies between files.
@@ -309,7 +321,7 @@ pub fn fclonefileat<Fd: AsFd, DstFd: AsFd, P: path::Arg>(
     let srcfd = src.as_fd();
     let dst_dirfd = dst_dir.as_fd();
     dst.into_with_z_str(|dst| {
-        imp::syscalls::fclonefileat(srcfd.as_fd(), dst_dirfd.as_fd(), &dst, flags)
+        imp::fs::syscalls::fclonefileat(srcfd.as_fd(), dst_dirfd.as_fd(), &dst, flags)
     })
 }
 
@@ -321,16 +333,17 @@ pub fn fclonefileat<Fd: AsFd, DstFd: AsFd, P: path::Arg>(
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/mknodat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/mknodat.2.html
-#[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi",)))]
+#[cfg(not(any(target_os = "ios", target_os = "macos", target_os = "wasi")))]
 #[inline]
 pub fn mknodat<P: path::Arg, Fd: AsFd>(
     dirfd: &Fd,
     path: P,
+    file_type: FileType,
     mode: Mode,
     dev: Dev,
 ) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::mknodat(dirfd, path, mode, dev))
+    path.into_with_z_str(|path| imp::fs::syscalls::mknodat(dirfd, path, file_type, mode, dev))
 }
 
 /// `fchownat(dirfd, path, owner, group, flags)`—Sets file or directory
@@ -342,7 +355,7 @@ pub fn mknodat<P: path::Arg, Fd: AsFd>(
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/fchownat.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/fchownat.2.html
-#[cfg(not(any(target_os = "wasi",)))]
+#[cfg(not(any(target_os = "wasi")))]
 #[inline]
 pub fn chownat<P: path::Arg, Fd: AsFd>(
     dirfd: &Fd,
@@ -352,5 +365,5 @@ pub fn chownat<P: path::Arg, Fd: AsFd>(
     flags: AtFlags,
 ) -> io::Result<()> {
     let dirfd = dirfd.as_fd();
-    path.into_with_z_str(|path| imp::syscalls::chownat(dirfd, path, owner, group, flags))
+    path.into_with_z_str(|path| imp::fs::syscalls::chownat(dirfd, path, owner, group, flags))
 }
