@@ -1,20 +1,22 @@
+//! libc syscalls supporting `rustix::net`.
+
 use super::super::c;
 use super::super::conv::{borrowed_fd, ret, ret_owned_fd, ret_send_recv, send_recv_len};
-use super::super::fd::BorrowedFd;
 use super::ext::{in6_addr_new, in_addr_new};
 #[cfg(not(windows))]
-use super::{encode_sockaddr_unix, SocketAddrUnix};
+use super::SocketAddrUnix;
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 use super::{
     encode_sockaddr_v4, encode_sockaddr_v6, read_sockaddr_os, AcceptFlags, AddressFamily, Protocol,
     RecvFlags, SendFlags, Shutdown, SocketFlags, SocketType,
 };
 use crate::as_ptr;
+use crate::fd::BorrowedFd;
 use crate::io::{self, OwnedFd};
 use crate::net::{SocketAddrAny, SocketAddrV4, SocketAddrV6};
 use core::convert::TryInto;
 use core::mem::{size_of, MaybeUninit};
-#[cfg(not(any(target_os = "redox", target_os = "wasi",)))]
+#[cfg(not(any(target_os = "redox", target_os = "wasi")))]
 use core::ptr::null_mut;
 
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))]
@@ -120,8 +122,8 @@ pub(crate) fn sendto_unix(
             buf.as_ptr().cast(),
             send_recv_len(buf.len()),
             flags.bits(),
-            as_ptr(&encode_sockaddr_unix(addr)).cast::<c::sockaddr>(),
-            size_of::<SocketAddrUnix>() as _,
+            as_ptr(&addr.unix).cast(),
+            addr.addr_len(),
         ))?
     };
     Ok(nwritten as usize)
@@ -185,8 +187,8 @@ pub(crate) fn bind_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io::Re
     unsafe {
         ret(c::bind(
             borrowed_fd(sockfd),
-            as_ptr(&encode_sockaddr_unix(addr)).cast(),
-            size_of::<c::sockaddr_un>() as c::socklen_t,
+            as_ptr(&addr.unix).cast(),
+            addr.addr_len(),
         ))
     }
 }
@@ -218,8 +220,8 @@ pub(crate) fn connect_unix(sockfd: BorrowedFd<'_>, addr: &SocketAddrUnix) -> io:
     unsafe {
         ret(c::connect(
             borrowed_fd(sockfd),
-            as_ptr(&encode_sockaddr_unix(addr)).cast(),
-            size_of::<c::sockaddr_un>() as c::socklen_t,
+            as_ptr(&addr.unix).cast(),
+            addr.addr_len(),
         ))
     }
 }
