@@ -25,10 +25,8 @@ use core::sync::atomic::Ordering::Relaxed;
 use linux_raw_sys::general::{__NR_clock_gettime, __kernel_clockid_t, __kernel_timespec};
 #[cfg(target_pointer_width = "32")]
 use {
-    super::conv::out,
-    linux_raw_sys::{
-        general::timespec as __kernel_old_timespec, v5_4::general::__NR_clock_gettime64,
-    },
+    super::conv::out, linux_raw_sys::general::__NR_clock_gettime64,
+    linux_raw_sys::general::timespec as __kernel_old_timespec,
 };
 
 #[inline]
@@ -58,14 +56,12 @@ pub(crate) fn clock_gettime_dynamic(which_clock: DynamicClockId<'_>) -> io::Resu
         }
 
         DynamicClockId::RealtimeAlarm => {
-            linux_raw_sys::v5_4::general::CLOCK_REALTIME_ALARM as __kernel_clockid_t
-        }
-        DynamicClockId::Tai => linux_raw_sys::v5_4::general::CLOCK_TAI as __kernel_clockid_t,
-        DynamicClockId::Boottime => {
-            linux_raw_sys::v5_4::general::CLOCK_BOOTTIME as __kernel_clockid_t
+            linux_raw_sys::general::CLOCK_REALTIME_ALARM as __kernel_clockid_t
         }
+        DynamicClockId::Tai => linux_raw_sys::general::CLOCK_TAI as __kernel_clockid_t,
+        DynamicClockId::Boottime => linux_raw_sys::general::CLOCK_BOOTTIME as __kernel_clockid_t,
         DynamicClockId::BoottimeAlarm => {
-            linux_raw_sys::v5_4::general::CLOCK_BOOTTIME_ALARM as __kernel_clockid_t
+            linux_raw_sys::general::CLOCK_BOOTTIME_ALARM as __kernel_clockid_t
         }
     };
 
@@ -261,29 +257,35 @@ unsafe fn _rustix_clock_gettime_via_syscall(
         void_star(res.cast::<c::c_void>()),
     );
     match ret(r0) {
-        Err(io::Error::NOSYS) => {
-            // Ordinarily `rustix` doesn't like to emulate system calls, but in
-            // the case of time APIs, it's specific to Linux, specific to
-            // 32-bit architectures *and* specific to old kernel versions, and
-            // it's not that hard to fix up here, so that no other code needs
-            // to worry about this.
-            let mut old_result = MaybeUninit::<__kernel_old_timespec>::uninit();
-            let r0 = syscall2(
-                nr(__NR_clock_gettime),
-                pass_usize(clockid as usize),
-                out(&mut old_result),
-            );
-            match ret(r0) {
-                Ok(()) => {
-                    let old_result = old_result.assume_init();
-                    *res = Timespec {
-                        tv_sec: old_result.tv_sec.into(),
-                        tv_nsec: old_result.tv_nsec.into(),
-                    };
-                    Ok(())
-                }
-                otherwise => otherwise,
-            }
+        Err(io::Error::NOSYS) => _rustix_clock_gettime_via_syscall_old(clockid, res),
+        otherwise => otherwise,
+    }
+}
+
+#[cfg(target_pointer_width = "32")]
+unsafe fn _rustix_clock_gettime_via_syscall_old(
+    clockid: c::c_int,
+    res: *mut Timespec,
+) -> io::Result<()> {
+    // Ordinarily `rustix` doesn't like to emulate system calls, but in
+    // the case of time APIs, it's specific to Linux, specific to
+    // 32-bit architectures *and* specific to old kernel versions, and
+    // it's not that hard to fix up here, so that no other code needs
+    // to worry about this.
+    let mut old_result = MaybeUninit::<__kernel_old_timespec>::uninit();
+    let r0 = syscall2(
+        nr(__NR_clock_gettime),
+        pass_usize(clockid as usize),
+        out(&mut old_result),
+    );
+    match ret(r0) {
+        Ok(()) => {
+            let old_result = old_result.assume_init();
+            *res = Timespec {
+                tv_sec: old_result.tv_sec.into(),
+                tv_nsec: old_result.tv_nsec.into(),
+            };
+            Ok(())
         }
         otherwise => otherwise,
     }
@@ -353,24 +355,41 @@ fn init() {
     minimal_init();
 
     if let Some(vdso) = vdso::Vdso::new() {
+        // Look up the platform-specific `clock_gettime` symbol as documented
+        // [here], except on 32-bit platforms where we look up the
+        // `64`-suffixed variant and fail if we don't find it.
+        //
+        // [here]: https://man7.org/linux/man-pages/man7/vdso.7.html
         #[cfg(target_arch = "x86_64")]
         let ptr = vdso.sym(zstr!("LINUX_2.6"), zstr!("__vdso_clock_gettime"));
         #[cfg(target_arch = "arm")]
-        let ptr = vdso.sym(zstr!("LINUX_2.6"), zstr!("__vdso_clock_gettime"));
+        let ptr = vdso.sym(zstr!("LINUX_2.6"), zstr!("__vdso_clock_gettime64"));
         #[cfg(target_arch = "aarch64")]
         let ptr = vdso.sym(zstr!("LINUX_2.6.39"), zstr!("__kernel_clock_gettime"));
         #[cfg(target_arch = "x86")]
         let ptr = vdso.sym(zstr!("LINUX_2.6"), zstr!("__vdso_clock_gettime64"));
         #[cfg(target_arch = "riscv64")]
-        let ptr = vdso.sym(zstr!("LINUX_4.15"), zstr!("__kernel_clock_gettime"));
+        let ptr = vdso.sym(zstr!("LINUX_4.15"), zstr!("__vdso_clock_gettime"));
 
-        assert!(!ptr.is_null());
+        // On all 64-bit platforms, the 64-bit `clock_gettime` symbols are
+        // always available.
+        #[cfg(any(target_pointer_width = "64"))]
+        let ok = true;
 
-        // Safety: Store the computed function addresses in static storage
-        // so that we don't need to compute it again (but if we do, it doesn't
-        // hurt anything).
-        unsafe {
-            CLOCK_GETTIME.store(ptr as usize, Relaxed);
+        // On some 32-bit platforms, the 64-bit `clock_gettime` symbols are not
+        // available on older kernel versions.
+        #[cfg(any(target_arch = "arm", target_arch = "x86"))]
+        let ok = !ptr.is_null();
+
+        if ok {
+            assert!(!ptr.is_null());
+
+            // Safety: Store the computed function addresses in static storage
+            // so that we don't need to compute it again (but if we do, it doesn't
+            // hurt anything).
+            unsafe {
+                CLOCK_GETTIME.store(ptr as usize, Relaxed);
+            }
         }
 
         // On x86, also look up the vsyscall entry point.
