@@ -5,8 +5,6 @@ use crate::net::SocketAddrUnix;
 use crate::net::{SocketAddrAny, SocketAddrV4, SocketAddrV6};
 use crate::{imp, io};
 use imp::fd::AsFd;
-#[cfg(windows)]
-use imp::fd::AsSocketAsFd;
 
 pub use imp::net::{RecvFlags, SendFlags};
 
@@ -15,15 +13,15 @@ pub use imp::net::{RecvFlags, SendFlags};
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/recv.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/recv.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-recv
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-recv
 #[inline]
 pub fn recv<Fd: AsFd>(fd: &Fd, buf: &mut [u8], flags: RecvFlags) -> io::Result<usize> {
     let fd = fd.as_fd();
-    imp::syscalls::recv(fd, buf, flags)
+    imp::net::syscalls::recv(fd, buf, flags)
 }
 
 /// `send(fd, buf, flags)`—Writes data to a socket.
@@ -31,15 +29,15 @@ pub fn recv<Fd: AsFd>(fd: &Fd, buf: &mut [u8], flags: RecvFlags) -> io::Result<u
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/send.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/send.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-send
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-send
 #[inline]
 pub fn send<Fd: AsFd>(fd: &Fd, buf: &[u8], flags: SendFlags) -> io::Result<usize> {
     let fd = fd.as_fd();
-    imp::syscalls::send(fd, buf, flags)
+    imp::net::syscalls::send(fd, buf, flags)
 }
 
 /// `recvfrom(fd, buf, flags, addr, len)`—Reads data from a socket and
@@ -48,11 +46,11 @@ pub fn send<Fd: AsFd>(fd: &Fd, buf: &[u8], flags: SendFlags) -> io::Result<usize
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/recvfrom.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/recvfrom.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-recvfrom
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-recvfrom
 #[inline]
 pub fn recvfrom<Fd: AsFd>(
     fd: &Fd,
@@ -60,7 +58,7 @@ pub fn recvfrom<Fd: AsFd>(
     flags: RecvFlags,
 ) -> io::Result<(usize, SocketAddrAny)> {
     let fd = fd.as_fd();
-    imp::syscalls::recvfrom(fd, buf, flags)
+    imp::net::syscalls::recvfrom(fd, buf, flags)
 }
 
 /// `sendto(fd, buf, flags, addr, sizeof(struct sockaddr_in))`—Writes data to
@@ -69,11 +67,11 @@ pub fn recvfrom<Fd: AsFd>(
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/sendto.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/sendto.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
 #[inline]
 #[doc(alias = "sendto")]
 pub fn sendto_v4<Fd: AsFd>(
@@ -83,7 +81,7 @@ pub fn sendto_v4<Fd: AsFd>(
     addr: &SocketAddrV4,
 ) -> io::Result<usize> {
     let fd = fd.as_fd();
-    imp::syscalls::sendto_v4(fd, buf, flags, addr)
+    imp::net::syscalls::sendto_v4(fd, buf, flags, addr)
 }
 
 /// `sendto(fd, buf, flags, addr, sizeof(struct sockaddr_in6))`—Writes data
@@ -92,11 +90,11 @@ pub fn sendto_v4<Fd: AsFd>(
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/sendto.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/sendto.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
 #[inline]
 #[doc(alias = "sendto")]
 pub fn sendto_v6<Fd: AsFd>(
@@ -106,7 +104,7 @@ pub fn sendto_v6<Fd: AsFd>(
     addr: &SocketAddrV6,
 ) -> io::Result<usize> {
     let fd = fd.as_fd();
-    imp::syscalls::sendto_v6(fd, buf, flags, addr)
+    imp::net::syscalls::sendto_v6(fd, buf, flags, addr)
 }
 
 /// `sendto(fd, buf, flags, addr, sizeof(struct sockaddr_un))`—Writes data to
@@ -115,11 +113,11 @@ pub fn sendto_v6<Fd: AsFd>(
 /// # References
 ///  - [POSIX]
 ///  - [Linux]
-///  - [Winsock]
+///  - [Winsock2]
 ///
 /// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/sendto.html
 /// [Linux]: https://man7.org/linux/man-pages/man2/sendto.2.html
-/// [Winsock]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
+/// [Winsock2]: https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-sendto
 #[inline]
 #[doc(alias = "sendto")]
 #[cfg(not(windows))]
@@ -130,7 +128,7 @@ pub fn sendto_unix<Fd: AsFd>(
     addr: &SocketAddrUnix,
 ) -> io::Result<usize> {
     let fd = fd.as_fd();
-    imp::syscalls::sendto_unix(fd, buf, flags, addr)
+    imp::net::syscalls::sendto_unix(fd, buf, flags, addr)
 }
 
 // TODO: `recvmsg`, `sendmsg`
