@@ -1,4 +1,5 @@
-//! Low-level implementation details for libc-like runtime libraries.
+//! Low-level implementation details for libc-like runtime libraries such as
+//! [origin].
 //!
 //! These functions are for implementing thread-local storage (TLS),
 //! managing threads, loaded libraries, and other process-wide resources.
@@ -9,6 +10,8 @@
 //! The API for these functions is not stable, and this module is
 //! `doc(hidden)`.
 //!
+//! [origin]: https://github.com/sunfishcode/mustang/tree/main/origin
+//!
 //! # Safety
 //!
 //! This module is intended to be used for implementing a runtime library
@@ -110,7 +113,7 @@ pub unsafe fn exit_thread(status: i32) -> ! {
 #[doc(alias = "_Exit")]
 #[inline]
 pub fn exit_group(status: i32) -> ! {
-    imp::syscalls::exit_group(status)
+    imp::process::syscalls::exit_group(status)
 }
 
 /// Return fields from the main executable segment headers ("phdrs") relevant
